Ext.namespace('dSA', 'dSA.util');

dSA.util.shortDSUID = function(dsuid) {
    if (!dsuid)
    {
        return "";
    }

    if (dsuid.length > 10)
    {
        // slice out serial number
        return dsuid.slice(dsuid.length - 10, dsuid.length - 2);
    }
    else
    {
        return dsuid;
    }
};

dSA.util.getName = function(name) {
    if ((name === undefined) || (name.length === 0))
    {
        return '<i>' + dSA._("no name") + '</i>';
    }
    else
    {
        return name;
    }
};

dSA.util.getData = function(response)
{
    var json = Ext.util.JSON.decode(response.responseText);
    if (json.success === false)
    {
        throw json.message;
    }

    if (json.data === undefined)
    {
        throw dSA._("could not retrieve data from response");
    }
    return json.data;
};

dSA.util.checkResponse = function(response)
{
    var json = Ext.util.JSON.decode(response.responseText);
    if (json.success === false)
    {
        throw json.message;
    }
};

dSA.util.failureMessage = function(response)
{
    try
    {
        var json = Ext.util.JSON.decode(response.responseText);
        if (json.message)
        {
            return json.message;
        }
    }
    catch (error)
    {
        // when the dSA is not running lighttpds proxy will return an
        // HTTP 500 along with some HTML which will cause a JSON parsing error
        return "";
    }
};

dSA.util.colon = function(text)
{
    if ((text === undefined) || (String(text).length === 0))
    {
        return "";
    }

    return ": " + text;
};


// this function never fails
dSA.util.getNumDevices = function(dsuid, callback)
{
    if (callback === undefined)
    {
        return;
    }

    Ext.Ajax.request({
        url: '/dsa/json/hardware/get',
        disableCaching: true,
        method: 'GET',
        params:
        {
            dsm: dsuid
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if ((data.dsms === undefined) && (data.dsms.length === 0))
                {
                    callback(0);
                }

                if (data.dsms[0].dsuid === dsuid) {
                    callback(data.dsms[0].devices.length);
                    return;
                }
            }
            catch (error)
            {}

            callback(0);
        },
        failure: function(response, opts)
        {
            callback(0);
        }
    });
};

dSA.util.unmask = function(maskEl)
{
    if (maskEl !== undefined)
    {
        maskEl.unmask();
    }
};

dSA.util.mask = function(maskEl, text)
{
    if (maskEl !== undefined)
    {
        maskEl.mask();
    }
};

dSA.util.ButtonKeyType =
{
    "ROOM_BUTTON_1_WAY"         : 0,
    "ROOM_BUTTON_2_WAY_DOWN"    : 1,
    "ROOM_BUTTON_2_WAY_UP"      : 2,
    "LOCAL_BUTTON_1_WAY"        : 4,
    "LOCAL_BUTTON_2_WAY_DOWN"   : 5,
    "LOCAL_BUTTON_2_WAY_UP"     : 6
};

dSA.util.PushButtonModeToString = function(buttonMode, keyType, buttonIndex,
                                            buttonCount) {
    var ret = "";
    var displayLine = 0;

    switch (keyType)
    {
        default:
        case dSA.util.ButtonKeyType.ROOM_BUTTON_1_WAY:
        case dSA.util.ButtonKeyType.LOCAL_BUTTON_1_WAY:
            displayLine = 1;
            break;
        case dSA.util.ButtonKeyType.ROOM_BUTTON_2_WAY_DOWN:
        case dSA.util.ButtonKeyType.LOCAL_BUTTON_2_WAY_DOWN:
        case dSA.util.ButtonKeyType.ROOM_BUTTON_2_WAY_UP:
        case dSA.util.ButtonKeyType.LOCAL_BUTTON_2_WAY_UP:
            ret = dSA._("2-Way")+ ", " + dSA._("Button-Type") + " " + keyType;
            break;
    }

    if ((buttonCount > 1) && (displayLine > 0))
    {
        if(ret !==  "")
        {
            ret = dSA._("Line") + " " + (buttonIndex+1) + ", " + ret;
        }
        else
        {
            ret = dSA._("Line") + " " + (buttonIndex+1);
        }
    }

    return ret;
};

dSA.util.reloaddSSUI = function() {
   if (dSS.module === true) {
       dSS.MessageBus.fireEvent('reloadapartment');
       dSS.config.firstLoad = false;
   }
};
